      subroutine amuelr (s1,s2,theta,numang,sign, 
     &                                     s11nor,s11,s12,s33,s34,pol)
c
c **********************************************
c
c subroutine amuelr computes Mueller matrix elements for either
c spheres or infinite cylinders
c
c       Merrill Milham      >>> version: 2.0 <<<        JANUARY 1994
c
c inputs :
c
c           s1 = amplitude scattering matrix element array.(complex*16)
c           s2 = amplitude scattering matrix element array.(complex*16)
c        theta = scattering angle array (real*8)
c       numang = the number of scattering angles, i.e., number of
c                elements in s1, s2. (integer)
c         sign = arbitrary sign (+1 or -1) used to adjust the sign of
c                s34 according to the users convention. (integer)
c
c outputs :
c
c      s11nor = s11 for a scattering angle of zero degrees, which
c               is used to normalize s11(theta) (real*8)
c         s11 = Mueller matrix element 1,l (real*8)
c         s12 = Mueller matrix element 1,2 (real*8)
c         s33 = Mueller matrix element 3,3 (real*8)
c         s34 = Mueller matrix element 3,4 (real*8)
c         pol = polarization = pol=-s12/s11 (real*8)
c
c         s12,s33,s34 are normalized by s11(theta)
c
c subroutines used: none
c
c *************************************************
c
      implicit none
*
      complex*16 s1(1),s2(1)
      real*8 theta(1),s11nor
      integer numang,sign
*
      real*8 s11(1),s12(1),s33(1),s34(1)
      real*8 pol(1)
*
      real*8 rs1,is1,rs2,is2,s11i
      real*8 ts11,ts12,half,zero,one
      parameter (half=0.5d0,zero=0.d0,one=1.d0)
      complex*16 ts
      integer i
c
      do 100 i=1,numang
      rs1=dble(s1(i))
      is1=dimag(s1(i))
      rs2=dble(s2(i))
c
c page 37 
c
      is2=dimag(s2(i)) 
*
      ts11=rs1*rs1+is1*is1
      ts12=rs2*rs2+is2*is2
      s11(i)=half*(ts11+ts12)
      s12(i)=half*(ts12-ts11) 
*
      if(s11(i).ne.zero) then
            s11i=s11(i)
                          else
            s11i=one
            write(*,*)
            write(*,*) 'Unnormalized Mueller matrix elements for ',
     &                  theta(i),' deg.'
            write(*, *)
      end if 
*
      pol(i)=-s12(i)/s11i 
*
      ts=s2(i)*dconjg(s1(i))
      s33(i)=dble(ts)
      s33(i)=s33(i)/s11i
      s34(i)=sign*dimag(ts)
      s34(i)=s34(i)/s11i 
*
      if(i.eq.1) s11nor=s11i 
*
      s11(i)=s11i/s11nor
100   continue
c
      return
c
      end
c
c page 38 
c