cthw  *********************************************************************
c
c     Program coded and tested by 
c     Thomas Wriedt, thw@iwt.uni-bremen.de, www.ScattPort.org
c     Bremen, Germany, 9. March 2010
c     
c     according to the report
c     Merril E. Milham, Electromagnetic scattering by magnetic spheres: 
c     theory and  algorithms, 
c     Edgewood Research Development and Engineering Center, 
c     ERDEC-TR-207,  Oct. 1994, ADA289798.
c
c     The program is available via 
c     www.scattport.org/index.php/programs-menu/
c     mie-type-codes-menu/70-mie-code-magnetic-sphere
c
c     Compiler: Intel(R) Fortran Compiler
c 
c     Program changes: 
c     - missing SLATEC subroutines added
c     - zabs and zsqrt replayed by abs and sqrt 
c     - parameter input via input.dat file
c     - pages numbers refer to the report
c     - changes are marked by cthw
c
c
cthw  *********************************************************************
c 
c	APPENDIX A
c     PROGRAM LISTINGS
c
      program msmain
c 
c *************************************************************************
c
c Program msmain computes the electromagnetic scattering for magnetic
c spheres. If the sphere is small a comparison is made between the
c results of a rigorous, complete calculation and an approximate
c calculation valid for small spheres.
c
c     Merrill Milham    >>> version 1.0 <<<     JANUARY 1994
c
c inputs:
c               ALL INPUT IS IN LIST DIRECTED FORMAT
c
c     line #1
c               flag = 'r' for refractive index data or
c                      'p' for permittivity data (character*l)
c               mior = number of complex indexes or
c                      complex permittivities to be read (integer)
c                 mp = complex index or permittivity values
c                       to be read, up to 10 values (complex*16)
c     line #2
c                muu = complex permeability values to be read
c                      mior values are required (complex*16)
c     line #3
c                 nx = number of size parameters to be read (integer)
c                  x = size parameter values to be read (real*8)
c     line #4 anginc = angular increment in degrees which is
c                      added to zero to produce the angles at
c                      which the scattering is to be produced. 
c 					   Values of anginc are restricted to those
c                      for which mod(90,anginc).eq.zero. (real*8)
C
c output:
c           For each angle the following quantities are given:
c                   The complex scattered field amplitudes, the
c                   scattered intensity, the degree of polarization,
c                   the Mueller matrix elements, and the polarization.
C
c           Efficiency factors for extinction, scattering, absorption, and
c           backscatter, and the asymmetry factor.
C
c subroutines used:
C
c            magsph - returns computed scattering quantities for a
c                     homgeneous magnetic sphere or homogeneous
c                     nonmagnetic sphere if the permeability = (1,O)
C
c            amuelr - returns elements of the Mueller matrix for a
c                     spherical scatterer
C
c            msphsx - returns approximate scattering quantities for a
c                     small homogeneous, magnetic sphere or a small,
c
c page 21 
c
c                     homogeneous, nonmagnetic sphere if the
c                     permeability = (1,0)
c
c **************************************************************************
c
      implicit none 
*       
      integer nangl
      real*8 one,zero
      parameter (nangl=255,one=1.d0,zero=0.d0) 
*
      complex*16 s1(nangl),s2(nangl),sx1(nangl),sx2(nangl)
      complex*16 eps,mu,muu(10),mp(10)
*
      real*8 i1,i2,inten,theta(nangl),xx,x(10),anginc
      real*8 isx1,isx2,intsx,dgplsx,angle,degpol
      real*8 s11(nangl),s12(nangl),s33(nangl)
      real*8 s34(nangl),s11nor,pol(nangl)
      real*8 sx11(nangl),sx12(nangl),sx33(nangl)
      real*8 sx34(nangl),sxpol(nangl)
      real*8 qext,qsca,qbac,g,qabs
      real*8 qesx,qssx,qasx,qbsx
***   
      integer sign,mior,i,nx,nmang1,nmang2,nior,nxx 
*
      logical xflag 
      character*1 flag
cthw
	OPEN(UNIT=8,FILE='input.dat')
cthw
      write(*,*) 'read(*,*) flag,mior,(mp(i),i=1,mior)'
      read(8,*) flag,mior,(mp(i),i=1,mior)
      write(*,*) 'read(*,*) (muu(i),i=1,mior)'
      read(8,*) (muu(i),i=1,mior)
      write(*,*) 'read(*,*) nx,(x(i),i=1,nx)'
      read(8,*) nx,(x(i),i=1,nx)
      write(*,*) 'read(*,*) anginc'
      read(8,*) anginc
      write(*,*)
c
      if(dmod(90.d0,anginc).eq.zero) then
         continue
                                     else
         stop 'angular increment error'
      end if 
*
      nmang1=(180.d0/anginc)+1
      nmang2=(90.d0/anginc)+1 
*
      do 1 i = 1,nmang1
1     theta(i) = dble(i-1)*anginc
c
      do 100 nior = 1,mior
c
c page 22
c
      if(flag.eq.'p') then
            eps=mp(nior)
            else if(flag.eq.'r') then
                    eps=(mp(nior))**2
                else
                    stop 'material properties input error'
      end if
       
      mu=muu(nior)
*
      sign=1
c            
      do 100 nxx = 1,nx      
      xx=x(nxx)
cthw      xflag=xx*(zsqrt(mu*eps)).lt.one
      xflag=xx*abs(sqrt(mu*eps)).lt.one
*
      write(*,1008) xx,eps,mu
      if(flag.eq.'r') write(*,1000) xx,mp(nior)
c
      call magsph(xx,eps,mu,nmang2,theta,qext,qsca,qbac,g,s1,s2)
      qabs = qext-qsca
*
      s11nor=0.d0
      call amuelr(s1,s2,theta,nmang1,sign,s11nor,s11,s12,s33,s34,pol)
c
      if(xflag) then
      call msphsx(xx,mu,eps,nmang2,theta,qesx,qssx,qasx,qbsx,sx1,sx2)
      s11nor=0.d0
      call amuelr(sx1,sx2,theta,nmang1,sign,s11nor,sx11,sx12,sx33,sx34
     & 							,sxpol)
                       else
      continue
      end if
c
      do 10 i = 1,nmang1
      angle = theta(i)
*
      i1 = (dble(s1(i)))**2+(dimag(s1(i)))**2
      i2 = (dble(s2(i)))**2+(dimag(s2(i)))**2
      inten = 0.5*(i1+i2)
      if(.not.(i1.eq.zero.and.i2.eq.zero)) then
      degpol = (i2-i1)/(i2+i1)
                                           else
      write(*,*)
      write(*,*) 'degree of polarization undefined for ',angle,' deg'
      write(*,*)
      degpol=zero
      end if
*
      if(xflag) then
      isx1 = (dble(sx1(i)))**2+(dimag(sx1(i)))**2
      isx2 = (dble(sx2(i)))**2+(dimag(sx2(i)))**2
c
c page 23
c  
      intsx = 0.5*(isx1+isx2)
      if(.not.(isx1.eq.zero.and.isx2.eq.zero)) then
      dgplsx = (isx2-isx1)/(isx2+isx1)
                                                else
      write(*,*)
      write(*,*)'degree of polarization undefined for ',angle,' deg.sx'
      write(*,*)
      dgplsx=zero
      end if
                    else
      continue
      end if 
*
      write (*,1004)
      write(*,1001) angle,s1(i),s2(i)
      if(xflag) write(*,1001) angle,sx1(i),sx2(i)
      write(*,*)
      write (*, 1005)
      write(*,1006) inten,degpol
      if(xflag) write(*,1006) intsx,dgplsx
      write(*,*)
      write (*,1007)
      write(*,1003) s11(i),s12(i),s33(i),s34(i),pol(i)
      if(xflag) write(*,1003) sx11(i),sx12(i),sx33(i),sx34(i),sxpol(i)
10    write(*,*)
      write (*, 1002) qext, qsca, qabs,g,qbac
      if(xflag) write(*,1002) qesx,qssx,qasx,g,qbsx
      write(*,*)
100   continue
c
      stop
c
1000  format(1x,'Mie size parameter =',f10.5,5x,'refractive index =' 
     + ,f7.3,e12.3//)
1001  format(f7.2,4e14.6)
1002  format( /29x,'extinction   scattering   absorption'/ 
     + 7x,'efficiency factors',3e14.6/ 7x,'asymmetry factor =',f9.6,
     & 7x,'backscatter =',e14.6)
1003  format(5e14.6)
1004  format (' angle',11x,'s-sub-1',21x,'s-sub-2')
1005  format (11x,'intensity',4x,'deg of polzn')
1006  format(7x,2e14.6)
1007  format(7x,'s11',11x,'s12',11x,'s33',11x,'s34',11x,'pol')
1008  format(1x,'Mie size parameter =',f10.5,5x,'permittivity ='
     + ,2e12.3,/36x,'permeability =',2e12.3//)
c
      end