
      subroutine msphsx(x,mu,eps,ntheta,theta,
     & qext,qsca,qabs,qbac,s1,s2)
c
c **************************************************
c
c Subroutine msphsx computes an approximate values of the scattered amplitude!
c and scattering cross sections (efficiencies) for a magnetic sphere with
c small size parameters.
c
c     Merrill Milham        >>> version 1.2 <<<             DEC 1993
c
c     Inputs :
c              x = size parameter of the sphere (real*8)
c            eps = complex permittivity: epsr -i*epsi (complex*16)
c             mu = complex permeability: mur - i*mui (complex*16)
c         ntheta = number of scattering angles (integer)
c          theta = scattering angles in degrees (real*8)
c
c Outputs :
c             s1 = scattered amplitude
c             s2 = scattered amplitude
c           qext = extinction efficiency
c           qsca = scattering efficiency
c           qabs = absorption efficiency
c           qbac = backscatter efficiency
c
c References:
c
c M. Kerker, D.-S. Wang, and C. L. Giles, "Electromagnetic scattering
c by magnetic spheres," J. Opt. Soc. Am., 73, 765-767 (1983).
c
c J. A. Stratton, "Electromagnetic Theory," (McGraw-Hill, New York,
c 1941)
c
c ***********************************************
c
      real*8 x
      complex*16 mu,eps
      integer ntheta     
      real*8 theta(1)
*
      complex*16 s1(1),s2(1)
      real*8 qext,qsca,qabs,qbac
*
	real*8 xp,n,k,thetal
      complex*16 ef,mf,mui,epsi,cx
*
      real*8 zero,one,two,three,four,eight,c0,cpi,rad
      parameter (zero=0.d0,one=1.d0,two=2.d0,four=4.d0)
      parameter (three=3.d0,eight=8.d0,c0=eight/three)
      parameter (cpi=3.1415926535897932384d0,rad=cpi/180.d0)
      complex*16 cdble0,cdblei
c
c page 34
c
      parameter (cdble0=(0.d0,0.d0),cdblei=(0.d0,1.d0)) 
*
      integer nangl,nangl2
      parameter (nangl=255,nangl2=(nangl+1)/2)
cthw      real*8 xmu(nangl)
      real*16 xmu(nangl)
      integer l,j,j2,j3
c
      if(ntheta.eq.0) then
            s1(1)=cdble0
            s2(1)=cdble0
                        else
*
                if(ntheta.le.nangl2) then
                    continue
                                      else
       print *,ntheta,'scattering angles input: only',nangl2,' allowed'
                    stop
                endif 
*
      do 100 l=1,ntheta
      thetal=dabs(theta(l))
      theta(l)=thetal 
*
               if(thetal.le.90.d0) then
                continue
                                    else
      print*,'theta(',l,')=',thetal,'scattering angles must be <=90 deg'
            stop
            end if 
*
      thetal=rad*thetal
      xmu(l)=dcos(thetal)
100   continue
*
      end if
c
      n=dble(eps)
      k=dabs(dimag(eps))
      epsi=dcmplx(n,-k) 
*
      n=dble(mu)
      k=dabs(dimag(mu))
      mui=dcmplx(n,-k)
c
      ef=(epsi-one)/(epsi+two)
      mf=(mui-one)/(mui+two) 
*
      xp=x*x*x
      cx=dcmplx(zero,xp)
c
      if(ntheta.eq.0) then
            continue
c
c page 35
c
            else
      	j2=2*ntheta
      	do 500 j=1,ntheta
      	j3=j2-j
      	s1(j)=cx*(ef+mf*xmu(j))
      	s2(j)=cx*(ef*xmu(j)+mf)
      	s1(j3)=cx*(ef-mf*xmu(j))
      	s2(j3)=cx*(mf-ef*xmu(j))
500   continue
      end if
c
      xp=xp*x
      qext=-four*x*dimag(ef+mf)
cthw	  qsca=c0*xp*(zabs(ef)**2+(mf)**2)
      qsca=c0*xp*(abs(ef)**2+abs(mf)**2)
      
      if(qext.le.zero) qext=qsca
      qabs=ddim(qext,qsca)
cthw      qbac=four*xp*(zabs(ef-mf))**2
      qbac=four*xp*(abs(ef-mf))**2
c
      return
c
      end